
# Changelog
All notable changes to tailbone-nationbuilder will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v0.2.0 (2024-06-11)

### Feat

- switch from setup.cfg to pyproject.toml + hatchling

## [0.1.3] - 2023-09-16
### Changed
- Add grid totals support for NB donations.

## [0.1.2] - 2023-09-15
### Changed
- Use handler to generate NationBuilder URLs.

## [0.1.1] - 2023-09-12
### Changed
- Add views for NationBuilder donations cache.

## [0.1.0] - 2023-09-12
### Added
- Initial version, to expose NationBuilder cache tables.
